import pytest


class BugzillaPlugin(object):
    def __init__(self, client, api_details):
        self.client = client
        self.api_details = api_details
        self.bug = api_details['bug']
        self.bugzilla_host = api_details['bugzilla_host']
        self.results = list()
        self.username = api_details['username']
        self.password = api_details['password']

    @pytest.hookimpl(tryfirst=True, hookwrapper=True)
    def pytest_runtest_makereport(self, item, call):
        outcome = yield
        rep = outcome.get_result()
        if rep.when == 'call':
            '''
            The test result returns a tuple that contains the path of the
            test, the line number an assertion was on, and the 'domain' of
            the test, which is the name of the test method the assertion was
            part of
            '''
            location = rep.location
            test_name = location[2]
            self.results.append("{0} -> {1}".format(test_name, rep.outcome))

    def pytest_sessionfinish(self):
        # Build payload to send
        test_results = "Test output generated by pytest-bugzilla-notifier\n\n"
        for result in self.results:
            test_results += "{}\n".format(result)
        return self.post_results(test_results)

    def post_results(self, test_results):
        return self.client.bug_update(test_results, self.bug)
